@@ -6,12 +6,9 @@ from mypy_extensions import TypedDict
 class RelayHeader(TypedDict):
     raw: bytes
     hash: bytes
-    hash_le: bytes
     height: int
     prevhash: bytes
-    prevhash_le: bytes
     merkle_root: bytes
-    merkle_root_le: bytes
 
 
 class SPVProof(TypedDict):
@@ -21,7 +18,6 @@ class SPVProof(TypedDict):
     vout: bytes
     locktime: bytes
     tx_id: bytes
-    tx_id_le: bytes
     index: int
     intermediate_nodes: bytes
     confirming_header: RelayHeader
